==> haskell-decimal-0.5.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-56zVtZJqKOTFIT1hax0CPK
key: Decimal-0.5.1-56zVtZJqKOTFIT1hax0CPK
license: BSD3
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
author: Paul Johnson
exposed: True
indefinite: False
exposed-modules:
    Data.Decimal
abi: 893866a1195a99b9f541c9060b83f055
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-56zVtZJqKOTFIT1hax0CPK
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Decimal
version: 0.5.1
id: Decimal-0.5.1-IYHmhyk6baNg4MF1ZTjOY
key: Decimal-0.5.1-IYHmhyk6baNg4MF1ZTjOY
license: BSD3
copyright: Paul Johnson, 2013, 2018.
maintainer: paul@cogito.org.uk
stability: beta
homepage: https://github.com/PaulJohnson/Haskell-Decimal
synopsis: Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.
category: Math
author: Paul Johnson
exposed: True
indefinite: False
exposed-modules:
    Data.Decimal
abi: 7df586e1413b1afb0ea38c213b402847
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/Decimal-0.5.1
hs-libraries: HSDecimal-0.5.1-IYHmhyk6baNg4MF1ZTjOY
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html: /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
